#!/usr/bin/ruby
######################################################################
# Copyright (C) 2007, Ihar Hrachyshka <ihar.hrachyshka@gmail.com>
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
######################################################################
# System requirements:
# Ruby interpreter: tested for 1.8.x only (http://www.ruby-lang.org)
# Make sure you have "ruby" executable in your PATH environment!
# For Unix, make sure this file has "x" attribute enabled!
######################################################################
# Usage:
# $ ./lat2cyr [filename] # for Unix
# $ ruby ./lat2cyr [filename] # for others
# Program reads Belarusian Latin text from 'filename' file, or from
# stdin if 'filename' is not specified, and pipes cyrillic text to
# stdout. To save the results to a file, you should redirect it:
# $ ./lat2cyr [filename] > output_file
######################################################################
def lat2cyr(line)
	line.gsub!('bje', 'б\'е')
	line.gsub!('bjo', 'б\'ё')
	line.gsub!('bji', 'б\'і')
	line.gsub!('bju', 'б\'ю')
	line.gsub!('bja', 'б\'я')

	line.gsub!('Bje', 'Б\'е')
	line.gsub!('Bjo', 'Б\'ё')
	line.gsub!('Bji', 'Б\'і')
	line.gsub!('Bju', 'Б\'ю')
	line.gsub!('Bja', 'Б\'я')

	line.gsub!('ćje', 'цье')
	line.gsub!('ćjo', 'цьё')
	line.gsub!('ćji', 'цьі')
	line.gsub!('ćju', 'цью')
	line.gsub!('ćja', 'цья')

	line.gsub!('Ćje', 'Цье')
	line.gsub!('Ćjo', 'Цьё')
	line.gsub!('Ćji', 'Цьі')
	line.gsub!('Ćju', 'Цью')
	line.gsub!('Ćja', 'Цья')

	line.gsub!('dje', 'д\'е')
	line.gsub!('djo', 'д\'ё')
	line.gsub!('dji', 'д\'і')
	line.gsub!('dju', 'д\'ю')
	line.gsub!('dja', 'д\'я')

	line.gsub!('Dje', 'Д\'е')
	line.gsub!('Djo', 'Д\'ё')
	line.gsub!('Dji', 'Д\'і')
	line.gsub!('Dju', 'Д\'ю')
	line.gsub!('Dja', 'Д\'я')

	line.gsub!('fje', 'ф\'е')
	line.gsub!('fjo', 'ф\'ё')
	line.gsub!('fji', 'ф\'і')
	line.gsub!('fju', 'ф\'ю')
	line.gsub!('fja', 'ф\'я')

	line.gsub!('Fje', 'Ф\'е')
	line.gsub!('Fjo', 'Ф\'ё')
	line.gsub!('Fji', 'Ф\'і')
	line.gsub!('Fju', 'Ф\'ю')
	line.gsub!('Fja', 'Ф\'я')

	line.gsub!('gje', 'ґ\'е')
	line.gsub!('gjo', 'ґ\'ё')
	line.gsub!('gji', 'ґ\'і')
	line.gsub!('gju', 'ґ\'ю')
	line.gsub!('gja', 'ґ\'я')

	line.gsub!('Gje', 'Ґ\'е')
	line.gsub!('Gjo', 'Ґ\'ё')
	line.gsub!('Gji', 'Ґ\'і')
	line.gsub!('Gju', 'Ґ\'ю')
	line.gsub!('Gja', 'Ґ\'я')

	line.gsub!('hje', 'г\'е')
	line.gsub!('hjo', 'г\'ё')
	line.gsub!('hji', 'г\'і')
	line.gsub!('hju', 'г\'ю')
	line.gsub!('hja', 'г\'я')

	line.gsub!('Hje', 'Г\'е')
	line.gsub!('Hjo', 'Г\'ё')
	line.gsub!('Hji', 'Г\'і')
	line.gsub!('Hju', 'Г\'ю')
	line.gsub!('Hja', 'Г\'я')

	line.gsub!('kje', 'к\'е')
	line.gsub!('kjo', 'к\'ё')
	line.gsub!('kji', 'к\'і')
	line.gsub!('kju', 'к\'ю')
	line.gsub!('kja', 'к\'я')

	line.gsub!('Kje', 'К\'е')
	line.gsub!('Kjo', 'К\'ё')
	line.gsub!('Kji', 'К\'і')
	line.gsub!('Kju', 'К\'ю')
	line.gsub!('Kja', 'К\'я')

	line.gsub!('lje', 'лье')
	line.gsub!('ljo', 'льё')
	line.gsub!('lji', 'льі')
	line.gsub!('lju', 'лью')
	line.gsub!('lja', 'лья')

	line.gsub!('Lje', 'Лье')
	line.gsub!('Ljo', 'Льё')
	line.gsub!('Lji', 'Льі')
	line.gsub!('Lju', 'Лью')
	line.gsub!('Lja', 'Лья')

	line.gsub!('ńje', 'нье')
	line.gsub!('ńjo', 'ньё')
	line.gsub!('ńji', 'ньі')
	line.gsub!('ńju', 'нью')
	line.gsub!('ńja', 'нья')

	line.gsub!('Ńje', 'Нье')
	line.gsub!('Ńjo', 'Ньё')
	line.gsub!('Ńji', 'Ньі')
	line.gsub!('Ńju', 'Нью')
	line.gsub!('Ńja', 'Нья')

	line.gsub!('pje', 'п\'е')
	line.gsub!('pjo', 'п\'ё')
	line.gsub!('pji', 'п\'і')
	line.gsub!('pju', 'п\'ю')
	line.gsub!('pja', 'п\'я')

	line.gsub!('Pje', 'П\'е')
	line.gsub!('Pjo', 'П\'ё')
	line.gsub!('Pji', 'П\'і')
	line.gsub!('Pju', 'П\'ю')
	line.gsub!('Pja', 'П\'я')

	line.gsub!('rje', 'р\'е')
	line.gsub!('rjo', 'р\'ё')
	line.gsub!('rji', 'р\'і')
	line.gsub!('rju', 'р\'ю')
	line.gsub!('rja', 'р\'я')

	line.gsub!('Rje', 'Р\'е')
	line.gsub!('Rjo', 'Р\'ё')
	line.gsub!('Rji', 'Р\'і')
	line.gsub!('Rju', 'Р\'ю')
	line.gsub!('Rja', 'Р\'я')

	line.gsub!('śje', 'сье')
	line.gsub!('śjo', 'сьё')
	line.gsub!('śji', 'сьі')
	line.gsub!('śju', 'сью')
	line.gsub!('śja', 'сья')

	line.gsub!('Śje', 'Сье')
	line.gsub!('Śjo', 'Сьё')
	line.gsub!('Śji', 'Сьі')
	line.gsub!('Śju', 'Сью')
	line.gsub!('Śja', 'Сья')

	line.gsub!('tje', 'т\'е')
	line.gsub!('tjo', 'т\'ё')
	line.gsub!('tji', 'т\'і')
	line.gsub!('tju', 'т\'ю')
	line.gsub!('tja', 'т\'я')

	line.gsub!('Tje', 'Т\'е')
	line.gsub!('Tjo', 'Т\'ё')
	line.gsub!('Tji', 'Т\'і')
	line.gsub!('Tju', 'Т\'ю')
	line.gsub!('Tja', 'Т\'я')

	line.gsub!('źje', 'зье')
	line.gsub!('źjo', 'зьё')
	line.gsub!('źji', 'зьі')
	line.gsub!('źju', 'зью')
	line.gsub!('źja', 'зья')

	line.gsub!('Źje', 'Зье')
	line.gsub!('Źjo', 'Зьё')
	line.gsub!('Źji', 'Зьі')
	line.gsub!('Źju', 'Зью')
	line.gsub!('Źja', 'Зья')

	line.gsub!('Ba', 'Ба')
	line.gsub!('ba', 'ба')
	line.gsub!('Bie', 'Бе')
	line.gsub!('bie', 'бе')
	line.gsub!('Bio', 'Бё')
	line.gsub!('bio', 'бё')
	line.gsub!('Biu', 'Бю')
	line.gsub!('biu', 'бю')
	line.gsub!('Bia', 'Бя')
	line.gsub!('bia', 'бя')
	line.gsub!('Bi', 'Бі')
	line.gsub!('bi', 'бі')
	line.gsub!('Bo', 'Бо')
	line.gsub!('bo', 'бо')
	line.gsub!('Bu', 'Бу')
	line.gsub!('bu', 'бу')
	line.gsub!('By', 'Бы')
	line.gsub!('by', 'бы')
	line.gsub!('Be', 'Бэ')
	line.gsub!('be', 'бэ')

	line.gsub!('Ca', 'Ца')
	line.gsub!('ca', 'ца')
	line.gsub!('Cie', 'Це')
	line.gsub!('cie', 'це')
	line.gsub!('Cio', 'Цё')
	line.gsub!('cio', 'цё')
	line.gsub!('Ciu', 'Цю')
	line.gsub!('ciu', 'цю')
	line.gsub!('Cia', 'Ця')
	line.gsub!('cia', 'ця')
	line.gsub!('Ci', 'Ці')
	line.gsub!('ci', 'ці')
	line.gsub!('Co', 'Цо')
	line.gsub!('co', 'цо')
	line.gsub!('Cu', 'Цу')
	line.gsub!('cu', 'цу')
	line.gsub!('Cy', 'Цы')
	line.gsub!('cy', 'цы')
	line.gsub!('Ce', 'Цэ')
	line.gsub!('ce', 'цэ')

	line.gsub!('Ča', 'Ча')
	line.gsub!('ča', 'ча')
	line.gsub!('Čo', 'Чо')
	line.gsub!('čo', 'чо')
	line.gsub!('Ču', 'Чу')
	line.gsub!('ču', 'чу')
	line.gsub!('Čy', 'Чы')
	line.gsub!('čy', 'чы')
	line.gsub!('Če', 'Чэ')
	line.gsub!('če', 'чэ')

	line.gsub!('Cha', 'Ха')
	line.gsub!('cha', 'ха')
	line.gsub!('Chie', 'Хе')
	line.gsub!('chie', 'хе')
	line.gsub!('Chio', 'Хё')
	line.gsub!('chio', 'хё')
	line.gsub!('Chiu', 'Хю')
	line.gsub!('chiu', 'хю')
	line.gsub!('Chia', 'Хя')
	line.gsub!('chia', 'хя')
	line.gsub!('Chi', 'Хі')
	line.gsub!('chi', 'хі')
	line.gsub!('Cho', 'Хо')
	line.gsub!('cho', 'хо')
	line.gsub!('Chu', 'Ху')
	line.gsub!('chu', 'ху')
	line.gsub!('Chy', 'Хы')
	line.gsub!('chy', 'хы')
	line.gsub!('Che', 'Хэ')
	line.gsub!('che', 'хэ')

	line.gsub!('Da', 'Да')
	line.gsub!('da', 'да')
	line.gsub!('Do', 'До')
	line.gsub!('do', 'до')
	line.gsub!('Du', 'Ду')
	line.gsub!('du', 'ду')
	line.gsub!('Dy', 'Ды')
	line.gsub!('dy', 'ды')
	line.gsub!('De', 'Дэ')
	line.gsub!('de', 'дэ')

	line.gsub!('Dzie', 'Дзе')
	line.gsub!('dzie', 'дзе')
	line.gsub!('Dzio', 'Дзё')
	line.gsub!('dzio', 'дзё')
	line.gsub!('Dziu', 'Дзю')
	line.gsub!('dziu', 'дзю')
	line.gsub!('Dzia', 'Дзя')
	line.gsub!('dzia', 'дзя')
	line.gsub!('Dzi', 'Дзі') 
	line.gsub!('dzi', 'дзі') 

	line.gsub!('Dža', 'Джа')
	line.gsub!('dža', 'джа')
	line.gsub!('Džo', 'Джо')
	line.gsub!('džo', 'джо')
	line.gsub!('Džu', 'Джу')
	line.gsub!('džu', 'джу')
	line.gsub!('Džy', 'Джы')
	line.gsub!('džy', 'джы')
	line.gsub!('Dže', 'Джэ')
	line.gsub!('dže', 'джэ')

	line.gsub!('Fa', 'Фа')
	line.gsub!('fa', 'фа')
	line.gsub!('Fie', 'Фе')
	line.gsub!('fie', 'фе')
	line.gsub!('Fio', 'Фё')
	line.gsub!('fio', 'фё')
	line.gsub!('Fiu', 'Фю')
	line.gsub!('fiu', 'фю')
	line.gsub!('Fia', 'Фя')
	line.gsub!('fia', 'фя')
	line.gsub!('Fi', 'Фі')
	line.gsub!('fi', 'фі')
	line.gsub!('Fo', 'Фо')
	line.gsub!('fo', 'фо')
	line.gsub!('Fu', 'Фу')
	line.gsub!('fu', 'фу')
	line.gsub!('Fy', 'Фы')
	line.gsub!('fy', 'фы')
	line.gsub!('Fe', 'Фэ')
	line.gsub!('fe', 'фэ')

	line.gsub!('Ga', 'Ґа')
	line.gsub!('ga', 'ґа')
	line.gsub!('Gie', 'Ґе')
	line.gsub!('gie', 'ґе')
	line.gsub!('Gio', 'Ґё')
	line.gsub!('gio', 'ґё')
	line.gsub!('Giu', 'Ґю')
	line.gsub!('giu', 'ґю')
	line.gsub!('Gia', 'Ґя')
	line.gsub!('gia', 'ґя')
	line.gsub!('Gi', 'Ґі')
	line.gsub!('gi', 'ґі')
	line.gsub!('Go', 'Ґо')
	line.gsub!('go', 'ґо')
	line.gsub!('Gu', 'Ґу')
	line.gsub!('gu', 'ґу')
	line.gsub!('Gy', 'Ґы')
	line.gsub!('gy', 'ґы')
	line.gsub!('Ge', 'Ґэ')
	line.gsub!('ge', 'ґэ')

	line.gsub!('Ha', 'Га')
	line.gsub!('ha', 'га')
	line.gsub!('Hie', 'Ге')
	line.gsub!('hie', 'ге')
	line.gsub!('Hio', 'Гё')
	line.gsub!('hio', 'гё')
	line.gsub!('Hiu', 'Гю')
	line.gsub!('hiu', 'гю')
	line.gsub!('Hia', 'Гя')
	line.gsub!('hia', 'гя')
	line.gsub!('Hi', 'Гі')
	line.gsub!('hi', 'гі')
	line.gsub!('Ho', 'Го')
	line.gsub!('ho', 'го')
	line.gsub!('Hu', 'Гу')
	line.gsub!('hu', 'гу')
	line.gsub!('Hy', 'Гы')
	line.gsub!('hy', 'гы')
	line.gsub!('He', 'Гэ')
	line.gsub!('he', 'гэ')

	line.gsub!('Ka', 'Ка')
	line.gsub!('ka', 'ка')
	line.gsub!('Kie', 'Ке')
	line.gsub!('kie', 'ке')
	line.gsub!('Kio', 'Кё')
	line.gsub!('kio', 'кё')
	line.gsub!('Kiu', 'Кю')
	line.gsub!('kiu', 'кю')
	line.gsub!('Kia', 'Кя')
	line.gsub!('kia', 'кя')
	line.gsub!('Ki', 'Кі')
	line.gsub!('ki', 'кі')
	line.gsub!('Ko', 'Ко')
	line.gsub!('ko', 'ко')
	line.gsub!('Ku', 'Ку')
	line.gsub!('ku', 'ку')
	line.gsub!('Ky', 'Кы')
	line.gsub!('ky', 'кы')
	line.gsub!('Ke', 'Кэ')
	line.gsub!('ke', 'кэ')

	line.gsub!('Ła', 'Ла')
	line.gsub!('ła', 'ла')
	line.gsub!('Le', 'Ле')
	line.gsub!('le', 'ле')
	line.gsub!('Lo', 'Лё')
	line.gsub!('lo', 'лё')
	line.gsub!('Li', 'Лі')
	line.gsub!('li', 'лі')
	line.gsub!('Ło', 'Ло')
	line.gsub!('ło', 'ло')
	line.gsub!('Łu', 'Лу')
	line.gsub!('łu', 'лу')
	line.gsub!('Ły', 'Лы')
	line.gsub!('ły', 'лы')
	line.gsub!('Łe', 'Лэ')
	line.gsub!('łe', 'лэ')
	line.gsub!('Lu', 'Лю')
	line.gsub!('lu', 'лю')
	line.gsub!('La', 'Ля')
	line.gsub!('la', 'ля')
	
	line.gsub!('Ma', 'Ма')
	line.gsub!('ma', 'ма')
	line.gsub!('Mie', 'Ме')
	line.gsub!('mie', 'ме')
	line.gsub!('Mio', 'Мё')
	line.gsub!('mio', 'мё')
	line.gsub!('Miu', 'Мю')
	line.gsub!('miu', 'мю')
	line.gsub!('Mia', 'Мя')
	line.gsub!('mia', 'мя')
	line.gsub!('Mi', 'Мі')
	line.gsub!('mi', 'мі')
	line.gsub!('Mo', 'Мо')
	line.gsub!('mo', 'мо')
	line.gsub!('Mu', 'Му')
	line.gsub!('mu', 'му')
	line.gsub!('My', 'Мы')
	line.gsub!('my', 'мы')
	line.gsub!('Me', 'Мэ')
	line.gsub!('me', 'мэ')

	line.gsub!('Na', 'На')
	line.gsub!('na', 'на')
	line.gsub!('Nie', 'Не')
	line.gsub!('nie', 'не')
	line.gsub!('Nio', 'Нё')
	line.gsub!('nio', 'нё')
	line.gsub!('Niu', 'Ню')
	line.gsub!('niu', 'ню')
	line.gsub!('Nia', 'Ня')
	line.gsub!('nia', 'ня')
	line.gsub!('Ni', 'Ні')
	line.gsub!('ni', 'ні')
	line.gsub!('No', 'Но')
	line.gsub!('no', 'но')
	line.gsub!('Nu', 'Ну')
	line.gsub!('nu', 'ну')
	line.gsub!('Ny', 'Ны')
	line.gsub!('ny', 'ны')
	line.gsub!('Ne', 'Нэ')
	line.gsub!('ne', 'нэ')

	line.gsub!('Pa', 'Па')
	line.gsub!('pa', 'па')
	line.gsub!('Pie', 'Пе')
	line.gsub!('pie', 'пе')
	line.gsub!('Pio', 'Пё')
	line.gsub!('pio', 'пё')
	line.gsub!('Piu', 'Пю')
	line.gsub!('piu', 'пю')
	line.gsub!('Pia', 'Пя')
	line.gsub!('pia', 'пя')
	line.gsub!('Pi', 'Пі')
	line.gsub!('pi', 'пі')
	line.gsub!('Po', 'По')
	line.gsub!('po', 'по')
	line.gsub!('Pu', 'Пу')
	line.gsub!('pu', 'пу')
	line.gsub!('Py', 'Пы')
	line.gsub!('py', 'пы')
	line.gsub!('Pe', 'Пэ')
	line.gsub!('pe', 'пэ')

	line.gsub!('Ra', 'Ра')
	line.gsub!('ra', 'ра')
	line.gsub!('Ro', 'Ро')
	line.gsub!('ro', 'ро')
	line.gsub!('Ru', 'Ру')
	line.gsub!('ru', 'ру')
	line.gsub!('Ry', 'Ры')
	line.gsub!('ry', 'ры')
	line.gsub!('Re', 'Рэ')
	line.gsub!('re', 'рэ')

	line.gsub!('Sa', 'Са')
	line.gsub!('sa', 'са')
	line.gsub!('Sie', 'Се')
	line.gsub!('sie', 'се')
	line.gsub!('Sio', 'Сё')
	line.gsub!('sio', 'сё')
	line.gsub!('Siu', 'Сю')
	line.gsub!('siu', 'сю')
	line.gsub!('Sia', 'Ся')
	line.gsub!('sia', 'ся')
	line.gsub!('Si', 'Сі')
	line.gsub!('si', 'сі')
	line.gsub!('So', 'Со')
	line.gsub!('so', 'со')
	line.gsub!('Su', 'Су')
	line.gsub!('su', 'су')
	line.gsub!('Sy', 'Сы')
	line.gsub!('sy', 'сы')
	line.gsub!('Se', 'Сэ')
	line.gsub!('se', 'сэ')

	line.gsub!('Ša', 'Ша')
	line.gsub!('ša', 'ша')
	line.gsub!('Šo', 'Шо')
	line.gsub!('šo', 'шо')
	line.gsub!('Šu', 'Шу')
	line.gsub!('šu', 'шу')
	line.gsub!('Šy', 'Шы')
	line.gsub!('šy', 'шы')
	line.gsub!('Še', 'Шэ')
	line.gsub!('še', 'шэ')

	line.gsub!('Ta', 'Та')
	line.gsub!('ta', 'та')
	line.gsub!('To', 'То')
	line.gsub!('to', 'то')
	line.gsub!('Tu', 'Ту')
	line.gsub!('tu', 'ту')
	line.gsub!('Ty', 'Ты')
	line.gsub!('ty', 'ты')
	line.gsub!('Te', 'Тэ')
	line.gsub!('te', 'тэ')

	line.gsub!('Va', 'Ва')
	line.gsub!('va', 'ва')
	line.gsub!('Vie', 'Ве')
	line.gsub!('vie', 'ве')
	line.gsub!('Vio', 'Вё')
	line.gsub!('vio', 'вё')
	line.gsub!('Viu', 'Вю')
	line.gsub!('viu', 'вю')
	line.gsub!('Via', 'Вя')
	line.gsub!('via', 'вя')
	line.gsub!('Vi', 'Ві')
	line.gsub!('vi', 'ві')
	line.gsub!('Vo', 'Во')
	line.gsub!('vo', 'во')
	line.gsub!('Vu', 'Ву')
	line.gsub!('vu', 'ву')
	line.gsub!('Vy', 'Вы')
	line.gsub!('vy', 'вы')
	line.gsub!('Ve', 'Вэ')
	line.gsub!('ve', 'вэ')

	line.gsub!('Za', 'За')
	line.gsub!('za', 'за')
	line.gsub!('Zie', 'Зе')
	line.gsub!('zie', 'зе')
	line.gsub!('Zio', 'Зё')
	line.gsub!('zio', 'зё')
	line.gsub!('Ziu', 'Зю')
	line.gsub!('ziu', 'зю')
	line.gsub!('Zia', 'Зя')
	line.gsub!('zia', 'зя')
	line.gsub!('Zi', 'Зі')
	line.gsub!('zi', 'зі')
	line.gsub!('Zo', 'Зо')
	line.gsub!('zo', 'зо')
	line.gsub!('Zu', 'Зу')
	line.gsub!('zu', 'зу')
	line.gsub!('Zy', 'Зы')
	line.gsub!('zy', 'зы')
	line.gsub!('Ze', 'Зэ')
	line.gsub!('ze', 'зэ')

	line.gsub!('Ža', 'Жа')
	line.gsub!('ža', 'жа')
	line.gsub!('Žo', 'Жо')
	line.gsub!('žo', 'жо')
	line.gsub!('Žu', 'Жу')
	line.gsub!('žu', 'жу')
	line.gsub!('Žy', 'Жы')
	line.gsub!('žy', 'жы')
	line.gsub!('Že', 'Жэ')
	line.gsub!('že', 'жэ')

	line.gsub!('Dź', 'Дзь')
	line.gsub!('dź', 'дзь')
	line.gsub!('Ź', 'Зь')
	line.gsub!('ź', 'зь')
	line.gsub!('L', 'Ль')
	line.gsub!('l', 'ль')
	line.gsub!('Ń', 'Нь')
	line.gsub!('ń', 'нь')
	line.gsub!('Ś', 'Сь')
	line.gsub!('ś', 'сь')
	line.gsub!('Ć', 'Ць')
	line.gsub!('ć', 'ць')

	line.gsub!('B', 'Б')
	line.gsub!('b', 'б')
	line.gsub!('Ch', 'Х')
	line.gsub!('ch', 'х')
	line.gsub!('C', 'Ц')
	line.gsub!('c', 'ц')
	line.gsub!('Č', 'Ч')
	line.gsub!('č', 'ч')
	line.gsub!('Dz', 'Дз')
	line.gsub!('dz', 'дз')
	line.gsub!('Dž', 'Дж')
	line.gsub!('dž', 'дж')
	line.gsub!('D', 'Д')
	line.gsub!('d', 'д')
	line.gsub!('F', 'Ф')
	line.gsub!('f', 'ф')
	line.gsub!('G', 'Ґ')
	line.gsub!('g', 'ґ')
	line.gsub!('H', 'Г')
	line.gsub!('h', 'г')
	line.gsub!('K', 'К')
	line.gsub!('k', 'к')
	line.gsub!('Ł', 'Л')
	line.gsub!('ł', 'л')
	line.gsub!('M', 'М')
	line.gsub!('m', 'м')
	line.gsub!('N', 'Н')
	line.gsub!('n', 'н')
	line.gsub!('P', 'П')
	line.gsub!('p', 'п')
	line.gsub!('R', 'Р')
	line.gsub!('r', 'р')
	line.gsub!('S', 'С')
	line.gsub!('s', 'с')
	line.gsub!('Š', 'Ш')
	line.gsub!('š', 'ш')
	line.gsub!('T', 'Т')
	line.gsub!('t', 'т')
	line.gsub!('V', 'В')
	line.gsub!('v', 'в')
	line.gsub!('Ž', 'Ж')
	line.gsub!('ž', 'ж')
	line.gsub!('Z', 'З')
	line.gsub!('z', 'з')
                      
	line.gsub!('Je', 'Е')
	line.gsub!('je', 'е')
	line.gsub!('Jo', 'Ё')
	line.gsub!('jo', 'ё')
	line.gsub!('Ju', 'Ю')
	line.gsub!('ju', 'ю')
	line.gsub!('Ja', 'Я')
	line.gsub!('ja', 'я')
	line.gsub!('J', 'Й')
	line.gsub!('j', 'й')
	line.gsub!('A', 'А')
	line.gsub!('a', 'а')
	line.gsub!('I', 'І')
	line.gsub!('i', 'і')
	line.gsub!('O', 'О')
	line.gsub!('o', 'о')
	line.gsub!('U', 'У')
	line.gsub!('u', 'у')
	line.gsub!('Ŭ', 'Ў')
	line.gsub!('ŭ', 'ў')
	line.gsub!('Y', 'Ы')
	line.gsub!('y', 'ы')
	line.gsub!('E', 'Э')
	line.gsub!('e', 'э')
end

while line = gets
	lat2cyr(line)
	puts line
end
